@@ -1,8 +1,9 @@
 set_option_default <- function(...) {
   enumerate(list(...), function(key, value) {
     option <- getOption(key)
-    if (is.null(option))
+    if (is.null(option)) {
       do.call(base::options, stats::setNames(list(value), key))
+    }
   })
 }
 
